@@ -14,7 +14,6 @@
 #  limitations under the License.
 
 import os
-import re
 import sys
 import socket
 import signal
@@ -28,8 +27,7 @@ from datetime import datetime
 
 __all__ = ['Postgresql', 'skipIfNotFound']
 
-SEARCH_PATHS = (['/usr/local/pgsql'] +
-                glob('/usr/local/bin/*') +  # for FreeBSD/OpenBSD
+SEARCH_PATHS = (['/usr/local/pgsql', '/usr/local'] +
                 glob('/usr/lib/postgresql/*') +  # for Debian/Ubuntu
                 glob('/opt/local/lib/postgresql-*'))  # for MacPorts
 DEFAULT_SETTINGS = dict(auto_start=2,
@@ -37,7 +35,7 @@ DEFAULT_SETTINGS = dict(auto_start=2,
                         initdb=None,
                         initdb_args='-U postgres -A trust',
                         postmaster=None,
-                        postmaster_args='-h 127.0.0.1',
+                        postmaster_args='-h 127.0.0.1 -F',
                         pid=None,
                         port=None,
                         copy_data_from=None)
@@ -162,7 +160,7 @@ class Postgresql(object):
                 if os.waitpid(pid, os.WNOHANG)[0] != 0:
                     raise RuntimeError("*** failed to launch postmaster ***\n" + self.read_log())
 
-                if re.search('accept connections', self.read_log()):
+                if self.is_connection_available():
                     break
 
                 if (datetime.now() - exec_at).seconds > 10.0:
@@ -178,12 +176,12 @@ class Postgresql(object):
                     if cursor.fetchone()[0] <= 0:
                         cursor.execute('CREATE DATABASE test')
 
-    def stop(self, _signal=signal.SIGTERM):
+    def stop(self, _signal=signal.SIGINT):
         if self._owner_pid == os.getpid():
             self.terminate(_signal)
             self.cleanup()
 
-    def terminate(self, _signal=signal.SIGTERM):
+    def terminate(self, _signal=signal.SIGINT):
         if self.pid is None:
             return  # not started
 
@@ -199,7 +197,7 @@ class Postgresql(object):
                     raise RuntimeError("*** failed to shutdown postmaster (timeout) ***\n" + self.read_log())
 
                 sleep(0.1)
-        except:
+        except OSError:
             pass
 
         self.pid = None
@@ -218,6 +216,15 @@ class Postgresql(object):
         except Exception as exc:
             raise RuntimeError("failed to open file:tmp/postgresql.log: %r" % exc)
 
+    def is_connection_available(self):
+        try:
+            with psycopg2.connect(**self.dsn(dbname='template1')):
+                pass
+        except psycopg2.OperationalError:
+            return False
+        else:
+            return True
+
 
 def skipIfNotInstalled(arg=None):
     if sys.version_info < (2, 7):
@@ -261,7 +268,9 @@ def find_program(name, subdirs):
 
 
 def get_path_of(name):
-    path = subprocess.Popen(['which', name], stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()[0]
+    path = subprocess.Popen(['/usr/bin/which', name],
+                            stdout=subprocess.PIPE,
+                            stderr=subprocess.PIPE).communicate()[0]
     if path:
         return path.rstrip().decode('utf-8')
     else:
